#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# terrainbento documentation build configuration file, created by
# sphinx-quickstart on Tue Mar  6 11:22:35 2018.
#
# This file is execfile()d with the current directory set to its
# containing dir.
#
# Note that not all possible configuration values are present in this
# autogenerated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os
import sys

from unittest.mock import MagicMock


class Mock(MagicMock):
    @classmethod
    def __getattr__(cls, name):
        return MagicMock()


class MockTest(MagicMock):
    @classmethod
    def __getattr__(cls, name):
        return MagicMock()

    def bench():
        return MagicMock()

    def test():
        return MagicMock()


MOCK_MODULES = [
    "landlab",
    "landlab.io",
    "landlab.io.netcdf",
    "landlab.components",
    "landlab.graph",
    "Component",
    "FlowAccumulator",
    "PrecipitationDistribution",
    "FastscapeEroder",
    "LinearDiffuser",
    "StreamPowerSmoothThresholdEroder",
    "ErosionDeposition",
    "Space",
    "TaylorNonLinearDiffuser",
    "DepthDependentDiffuser",
    "ExponentialWeatherer",
    "DepthDependentTaylorDiffuser",
    "scipy",
    "scipy.interpolate",
    "scipy.special",
    "scipy.integrate",
    "scipy.stats",
    "yaml",
    "numpy",
    "numpy.testing",
    "nose",
    "nose.plugins",
    "nose.plugins.base",
    "doctests",
    "Doctest",
    "Tester",
    "doctests.Doctest",
    "test",
    "bench",
    "xarray",
    "dask",
    "glob",
]

sys.modules.update((mod_name, Mock()) for mod_name in MOCK_MODULES)

import terrainbento

# The short X.Y version.
version = terrainbento.__version__
# The full version, including alpha/beta/rc tags.
release = terrainbento.__version__

from datetime import date

sys.path.insert(0, ".")

# -- General configuration ------------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#
# needs_sphinx = "1.0"

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named "sphinx.ext.*") or your custom
# ones.
extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.doctest",
    "sphinx.ext.intersphinx",
    "sphinx.ext.todo",
    "sphinx.ext.coverage",
    "sphinx.ext.mathjax",
    "sphinx.ext.ifconfig",
    "sphinx.ext.viewcode",
    "sphinx.ext.githubpages",
    "sphinx.ext.napoleon",
    "sphinx.ext.autosummary",
]

# sphinx napoleon specifications
napoleon_numpy_docstring = True
napoleon_google_docstring = False
napoleon_include_init_with_doc = True

napoleon_include_special_with_doc = True
# napoleon_google_docstring = False

autodoc_warningiserror = False

autodoc_mock_imports = ["landlab", "numpy", "scipy", "yaml"]

# Add any paths that contain templates here, relative to this directory.
# templates_path = ["_templates"]

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
# source_suffix = [".rst", ".md"]
source_suffix = ".rst"

# The master toctree document.
master_doc = "index"

# General information about the project.
project = "terrainbento"
copyright = str(date.today().year) + u", The TerrainBento Team"
author = "The TerrainBento Team"

# The version info for the project you"re documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
# language = "python"

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This patterns also effect to html_static_path and html_extra_path
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]

# If true, the current module name will be prepended to all description
# unit titles (such as .. function::).
# add_module_names = True
add_module_names = False

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = "sphinx"

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = True


# -- Options for HTML output ----------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "alabaster"

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
#
# html_theme_options = {}

# The name of an image file (relative to this directory) to place at the top
# of the sidebar.
html_logo = "images/terrainbento_logo.png"

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
# html_static_path = ["_static"]

# Custom sidebar templates, must be a dictionary that maps document names
# to template names.
#
# This is required for the alabaster theme
# refs: http://alabaster.readthedocs.io/en/latest/installation.html#sidebars
html_sidebars = {
    "**": [
        "about.html",
        "navigation.html",
        "relations.html",  # needs "show_related": True theme option to display
        "searchbox.html",
        "donate.html",
    ]
}


# -- Options for HTMLHelp output ------------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = "terrainbentodoc"


# -- Options for LaTeX output ---------------------------------------------

latex_elements = {
    # The paper size ("letterpaper" or "a4paper").
    #
    # "papersize": "letterpaper",
    # The font size ("10pt", "11pt" or "12pt").
    #
    # "pointsize": "10pt",
    # Additional stuff for the LaTeX preamble.
    #
    # "preamble": "",
    # Latex figure (float) alignment
    #
    # "figure_align": "htbp",
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title,
#  author, documentclass [howto, manual, or own class]).
latex_documents = [
    (
        master_doc,
        "terrainbento.tex",
        "Terrainbento Documentation",
        "The TerranBento Team",
        "manual",
    )
]


# -- Options for manual page output ---------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [(master_doc, "terrainbento", "terrainbento Documentation", [author], 1)]


# -- Options for Texinfo output -------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (
        master_doc,
        "terrainbento",
        "terrainbento Documentation",
        author,
        "terrainbento",
        "One line description of project.",
        "Miscellaneous",
    )
]

# -- Options for Epub output ----------------------------------------------

# Bibliographic Dublin Core info.
epub_title = project
epub_author = author
epub_publisher = author
epub_copyright = copyright

# The unique identifier of the text. This can be a ISBN number
# or the project homepage.
#
# epub_identifier = ""

# A unique identification for the text.
#
# epub_uid = ""

# A list of files that should not be packed into the epub file.
epub_exclude_files = ["search.html"]


# Example configuration for intersphinx: refer to the Python standard library.
intersphinx_mapping = {
    "python": ("https://docs.python.org/2.7", None),
    "numpy": ("http://docs.scipy.org/doc/numpy/", None),
    "landlab": ("http://landlab.readthedocs.io/en/release/", None),
}
